@@ -3,7 +3,7 @@
 #
 #  Spatial Logistic Regression
 #
-#  $Revision: 1.63 $   $Date: 2022/08/11 03:53:48 $
+#  $Revision: 1.67 $   $Date: 2024/01/25 09:07:52 $
 #
 
 slrm <- function(formula, ..., data=NULL, offset=TRUE, link="logit",
@@ -403,6 +403,22 @@ print.summary.slrm <- function(x, ...) {
 
 coef.summary.slrm <- function(object, ...) { object$coefs.SE.CI }
 
+getglmdata.slrm <- function(object, ...) { object$Data$df }
+
+getglmfit.slrm <- function(object, ...) { object$Fit$FIT }
+
+getglmsubset.slrm <- function(object, ...) {
+  su <- getCall(object)$subset
+  if(is.null(su)) return(rep(TRUE, nrow(model.matrix(object))))
+  su <- try(eval(su, envir=environment(terms(object))))
+  if(inherits(su, "try-error")) 
+    warning("Internal error: unable to evaluate the subset")
+  return(su)
+}
+
+hasglmfit.slrm <- function(object) { TRUE }
+
+
 logLik.slrm <- function(object, ..., adjust=TRUE) {
   FIT  <- object$Fit$FIT
   ll <- -deviance(FIT)/2
@@ -633,6 +649,16 @@ model.images.slrm <- function(object, ...) {
 }
 
 update.slrm <- function(object, fmla, ..., evaluate=TRUE, env=parent.frame()) {
+  if(!missing(fmla) && is.ppp(X <- fmla)) {
+    ## idiom 'update(model, Pattern)'
+    covlist <- object$Data$covariates
+    Yname <- object$CallInfo$responsename
+    newdata <- append(covlist, setNames(list(X), Yname))
+    ## call this method again with new arguments
+    object <- update(object, data=newdata, ..., env=env)
+    return(object)
+  }
+  ## resume normal service
   z <- getCall(object)
   extras <- match.call(expand.dots = FALSE)$...
   if(!missing(fmla)) 
